# Copyright (c) 2008,2009 SFB/TR-55
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
#    * Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#
#    * Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in
#      the documentation and/or other materials provided with the
#      distribution.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

package globsig;

use strict;

use defs qw($opt_v $opt_dry);
use defs qw(BLUE GREEN RED);

#---------------------------------------------------------------------------------------------------
# Initialise GS network
#---------------------------------------------------------------------------------------------------

sub init($)
{
  my ($partition) = @_;

  if (scalar @{$$partition->{ncLst}} > 1) {
    die "No partition name defined\n" unless defined $$partition->{name};
    die "QROOT not defined\n" unless defined $ENV{QROOT};
  }

  my $out = ($opt_v < 2 ? "> /dev/null 2>&1" : "");

  # Set close flag on all nodes
  remote::exec($partition, "gsconfig -c $out");

  # Perform hard reset of global signals on all nodes
  remote::exec($partition, "gsconfig -f $out");

  # Drain spurious signals
  remote::exec($partition, "gsconfig -d $out");

  # Reset driver counters
  remote::exec($partition, "gsconfig -z $out");

  # Configure upper root levels (if number of nodes > 1)
  if (scalar @{$$partition->{ncLst}} > 1) {
    my $filename = undef;
    $filename = $ENV{QROOT} . "/sbin/muxup";
    if (not -f $filename) {
      $filename = $ENV{QROOT} . "/bin/muxup";
      if (not -f $filename) {
        die "cannot find muxup file";
      }
    }
    my $cmd = "$filename --queue=" . $$partition->{name};
    $cmd .= " >/dev/null 2>&1" if ($opt_v < 1);
    logger::debug("$cmd\n");
    if (defined $opt_dry) {
      logger::debug("DRY system($cmd)\n");
    }
    else {
      system("$cmd");
    }
    die "Execution failed: \"$cmd\"\n" if $?;
  }

  # Unset close flag on all nodes (if number of nodes > 1)
  if (scalar @{$$partition->{ncLst}} > 1) {
    remote::exec($partition, "gsconfig -C $out");
  }
}

1;
