# ------------
# QPACE / qrun
# ------------
#
# Logging interface
#
# $Id: logger.pm 3467 2010-04-06 20:01:35Z pleiter $
#---------------------------------------------------------------------------------------------------

package logger;

use strict;
use FileHandle;

use defs qw(LOG_ERROR LOG_INFO LOG_DEBUG);
use defs qw($opt_v);

my $FH = undef;

#---------------------------------------------------------------------------------------------------
# Open
#---------------------------------------------------------------------------------------------------

sub open()
{
  local *FH;

  *FH = \*STDERR;

  FH->autoflush(1);

  $FH = *FH;
}

#---------------------------------------------------------------------------------------------------
# Generic print routine
#---------------------------------------------------------------------------------------------------

sub _print
{
  return if ($#_ < 0);

  logger::open() unless (defined $FH);
  local *FH = $FH;

  my @caller = caller(2);
  my $sub = (scalar @caller ? "$caller[3]" : "main");

  printf FH "[%s|%10d] ", $sub, time();
  printf FH @_;
}


#---------------------------------------------------------------------------------------------------
# Print debugging messages
#---------------------------------------------------------------------------------------------------

sub debug
{
  return unless ($opt_v >= LOG_DEBUG);
  logger::_print(@_);
}


#---------------------------------------------------------------------------------------------------
# Print info level messages
#---------------------------------------------------------------------------------------------------

sub info
{
  return unless ($opt_v >= LOG_INFO);
  logger::_print(@_);
}


#---------------------------------------------------------------------------------------------------
# Print error messages
#---------------------------------------------------------------------------------------------------

sub error
{
  return unless ($opt_v >= LOG_ERROR);
  logger::_print(@_);
}


1;
