# ------------
# QPACE / qrun
# ------------
#
# Node object
#
# $Id: node.pm 3467 2010-04-06 20:01:35Z pleiter $
#---------------------------------------------------------------------------------------------------

package Node;

use strict;
use Net::Ping;

#---------------------------------------------------------------------------------------------------
# Constructor
#---------------------------------------------------------------------------------------------------

sub new
{
  my $class = shift;
  my @argv  = @_;

  my $self  = {};

  if (@argv == 2) {
    $self->{bp}   = shift @argv;
    $self->{nc}   = shift @argv;
    $self->{c}    = [];
  }
  elsif (@argv == 5) {
    $self->{bp}   = shift @argv;
    $self->{nc}   = shift @argv;
    $self->{c}    = [ @argv ];
  }
  else {
    die "Illegal number of arguments\n";
  }

  $self->{isUp} = undef;
  $self->{qrunStatus} = "UNKNOWN";

  bless ($self, $class);
  return $self;
}


#---------------------------------------------------------------------------------------------------
# Return hostname
#---------------------------------------------------------------------------------------------------

sub hostname()
{
  my $self = shift;

  my $s = sprintf "nc-%02d-%02d", $self->{bp}, $self->{nc};

  return $s;
}


#---------------------------------------------------------------------------------------------------
# Set colour coordinates
#---------------------------------------------------------------------------------------------------

sub setCpos($$$)
{
  my $self = shift;

  $self->{c} = [ @_ ];
}


#---------------------------------------------------------------------------------------------------
# String version of absolute position
#---------------------------------------------------------------------------------------------------

sub apos_str()
{
  my $self = shift;

  my $s = sprintf "%d:%d", $self->{bp}, $self->{nc};

  return $s;
}


#---------------------------------------------------------------------------------------------------
# String version of colour coordinates
#---------------------------------------------------------------------------------------------------

sub cpos_str()
{
  my $self = shift;

  die "Colour coordinates not initialised\n" unless (scalar(@{$self->{c}}) == 3);

  my $s = sprintf "(%d,%d,%d)", @{$self->{c}};

  return $s;
}


#---------------------------------------------------------------------------------------------------
# Verify node is up
#---------------------------------------------------------------------------------------------------

sub isUp
{
  my $self = shift;

  if (!defined $self->{isUp} || $self->{isUp} == 1) {
    my $p = Net::Ping->new();
    $self->{isUp} = $p->ping($self->hostname, 2) ? 1 : 0;
    $p->close();
  }

  return $self->{isUp};
}


1;
